# Generated by Django 3.0.5 on 2020-08-04 15:24

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("data", "0011_auto_20200804_1108")]

    operations = [
        migrations.AddField(
            model_name="person",
            name="current_role",
            field=django.contrib.postgres.fields.jsonb.JSONField(
                default=None, null=True
            ),
        )
    ]
